@@ -17,7 +17,7 @@ ANNOT_FIELD_KIDS_KEY = '/Kids'      # Kids key for older pdf versions
 ANNOT_VAL_KEY = '/V'
 ANNOT_RECT_KEY = '/Rect'
 
-def get_form_fields(input_pdf_path):
+def get_form_fields(input_pdf_path, sort=False, page_number=None):
     """
     Retrieves the form fields from a pdf to then be stored as a dictionary and
     passed to the write_fillable_pdf() function. Uses pdfrw.
@@ -32,7 +32,25 @@ def get_form_fields(input_pdf_path):
     data_dict = {}
 
     pdf = pdfrw.PdfReader(input_pdf_path)
+    count = 1
+    if page_number is not None:
+        if type(page_number) == int:
+            if page_number > 0:
+                if page_number <= len(pdf.pages):
+                    pass
+                else:
+                    raise ValueError(f"page_number must be inbetween 1 & {len(pdf.pages)}")
+            else:
+                raise ValueError(f"page_number must be inbetween 1 & {len(pdf.pages)}")
+        else:
+            raise ValueError(f"page_number must be an int")
     for page in pdf.pages:
+        if page_number is not None:
+            if count != page_number:
+                count += 1
+                continue
+            else:
+                print(f"Values From Page {page_number}")
         annotations = page[ANNOT_KEY]
         if annotations:
             for annotation in annotations:
@@ -64,10 +82,15 @@ def get_form_fields(input_pdf_path):
                                     data_dict[key] = annotation[ANNOT_VAL_KEY][1:]
                         except:
                             pass
-    return data_dict
+        if count == page_number:
+            break
+    if sort == True:
+        return dict(sorted(data_dict.items()))
+    else:
+        return data_dict
 
 
-def print_form_fields(input_pdf_path):
+def print_form_fields(input_pdf_path, sort=False, page_number=None):
     """
     Retrieves the form fields from get_form_fields(), then pretty prints
     the data_dict. Uses pdfrw.
@@ -78,7 +101,7 @@ def print_form_fields(input_pdf_path):
     Returns
     ---------
     """
-    data_dict = get_form_fields(input_pdf_path)
+    data_dict = get_form_fields(input_pdf_path, sort, page_number)
     print("{" + ",\n".join("{!r}: {!r}".format(k, v) for k, v in data_dict.items()) + "}")
 
 
